# Scala 中的延续

> 原文:[https://www.geeksforgeeks.org/continuations-in-scala/](https://www.geeksforgeeks.org/continuations-in-scala/)

scala 中**延续的主要思想是能够中断一个程序，保存它的控制状态，并在稍后的时间点恢复它。延续作为一个概念出现在网络上，可能有助于基于事件的编程。延续，尤其是带分隔符的延续，是一种通用的编程工具。最值得注意的是，我们对它们以受控的方式挂起和恢复顺序代码路径的能力感兴趣，而没有语法开销，也不依赖于虚拟机线程。
所以我们试着用一个恰当的例子来理解它。想象一个从网络返回一个字节的`read()`函数:**

```scala
def read: Byte 
```

这通常是同步(阻塞)函数的签名。毕竟，它有一个返回值，在正常的编程语言中，这意味着等待该值可用。一个连续读取两个字节并打印它们的程序如下所示:

> 选择位元组 1 =读取
> 印表机(位元组 1 =[位元组 1]【选择位元组 2 =读取
> 印表机(位元组 2 =[位元组 2])

问题是，在 web 浏览器或 node.js 或任何其他单线程、事件驱动的环境中，这是不可接受的。我们根本无法长时间封锁，否则，系统中不会发生其他情况。
这里的问题是，我们必须以一种有趣的风格写作，即使使用 Scala 的轻量级闭包语法。还要注意每次回调通常如何导致新的缩进级别。一些程序员设法习惯了这种风格，但是它不能以非常自然的方式表示控制流，并且这个问题随着程序的大小而增长。

> 导入 scala.util.continuations._
> 重置{
> val byte1 = shift(读取)
> println(" byte 1 =+byte 1)
> val byte 2 = shift(读取)
> println(" byte 2 =+byte 2 ")

我们注意到复位和移位结构。这些术语对于一个新来的人来说没有任何意义，但是它们很久以前就在一篇学术论文中引入了，所以在 Scala 中被重用。基本上，重置限定了延续。有了完全延续，程序的整个剩余部分将在延续的控制之下，但是在这里，无论是在重置块之前还是之后，都与延续完全无关。(还有，reset 可以返回值，虽然这里我们不关心。)

在这个例子中，跟随字母从 A 到 Z

```scala
reset {
  // A
  shift { cf: (Int=>Int) =>

    // B
    val eleven = cf(10)

    // E
    println(eleven)
    val oneHundredOne = cf(100)

    // H
    println(oneHundredOne)
    oneHundredOne
  }

}
```

**输出:**

```scala
11
101
```

在上面的例子中，当调用延续函数 **cf** 时:

1.  执行跳过移位块的其余部分，并在它的末尾重新开始。传递给 cf 的参数是执行继续时移位块“评估”的值。这对于每次调用 **cf** 可能是不同的。
2.  执行一直持续到复位块结束(如果没有块，则一直到调用复位)。**重置**块的结果(或参数为**重置()**如果没有块)是 **cf** 返回的结果。
3.  执行在 **cf** 之后继续，直到**换挡**块结束。
4.  执行跳过，直到**复位**块结束(或者调用复位？)

让我们再看一个例子:

```scala
reset {
    println("A")
    shift { k1: (Unit=>Unit) =>
        println("B")
        k1()
        println("C")
    }
    println("D")
    shift { k2: (Unit=>Unit) =>
        println("E")
        k2()
        println("F")
    }
    println("G")
}
```

**输出:**

```scala
A
B
D
E
G
F
C

```