# Scala 中的占位符语法

> 原文:[https://www.geeksforgeeks.org/placeholder-syntax-in-scala/](https://www.geeksforgeeks.org/placeholder-syntax-in-scala/)

让一切变得简洁的需求导致 Scala 提出了一种叫做**占位符语法**的东西。Scala 允许使用*下划线(表示为“_”)*作为一个或多个参数的占位符。我们可以将下划线视为需要用值填充的内容。但是，每个参数在函数文本中只能出现一次。
**注意:**在内部，下划线被扩展为一个函数的文字，该函数将输入作为 1 个参数，然后检查所提到的条件。同一规则适用于多个参数。多下划线表示多个参数，而不是重复使用同一个参数。因此，当您只想获取一个或多个参数一次时，将使用此语法。这种语法不支持重用。
我们借助一个例子来理解占位符语法。

**例 1:**
假设我们要检查数字是否大于 5。

```scala
scala> someNumbers.filter(_ > 5)
```

在上面的示例中，条件在内部扩展为:

```scala
scala> someNumbers.filter(x=>x>5) 
```

变量 x 已被下划线替换，以使函数更加简洁。

占位符语法也可以用来表示多个参数。

**例 2:**
假设我们要加两个数字。如果我们理解上面的例子，我们会认为两个数字相加的正常语法应该是:

```scala
scala> val f = _ + _ 
```

当它被传递给编译器时，它会给出一个错误，因为你没有提到编译器应该把哪种类型的数字作为输入。

```scala
val f = _ + _ 
       ˆ 
error: missing parameter type for expanded function ((x$1, x$2) => x$1.$plus(x$2)) 

```

我们应该提到我们期望从函数中得到的数字类型。类型可以在冒号(':')的帮助下传递给函数。请注意，在内部，

```scala
f = _ + _
```

扩展为

```scala
((x$1, x$2) => x$1.$plus(x$2)).
```

现在，使用函数将两个数字相加的正确占位符语法是:

```scala
scala> val f = (_: Int) + (_: Int) 
f: (Int, Int) => Int = <function> 

//Input  
scala> f(15, 10)
//Output 
res: Int = 25
```

**因此，在传递多个参数时，请确保我们指定了要传递的变量的类型**。这样编译器就能理解它需要接受什么样的输入。

**例 3:**

```scala
scala> r.map((x,y) => x + y / x min y)
```

在上面的例子中，参数使用了不止一次。在这种情况下，我们需要四个下划线。根据规则，参数的数量和下划线的数量必须相同，因此我们不能使用占位符语法。